# CreditMemo


## Properties

Name | Type | Description | Notes
------------ | ------------- | ------------- | -------------
**integration_id__ns** | **str** | ID of the corresponding object in NetSuite. Only available if you have installed the [Zuora Connector for NetSuite](https://www.zuora.com/connect/app/?appId&#x3D;265).  | [optional] 
**integration_status__ns** | **str** | Status of the credit memo&#39;s synchronization with NetSuite. Only available if you have installed the [Zuora Connector for NetSuite](https://www.zuora.com/connect/app/?appId&#x3D;265).  | [optional] 
**origin__ns** | **str** | Origin of the corresponding object in NetSuite. Only available if you have installed the [Zuora Connector for NetSuite](https://www.zuora.com/connect/app/?appId&#x3D;265).  | [optional] 
**sync_date__ns** | **str** | Date when the credit memo was synchronized with NetSuite. Only available if you have installed the [Zuora Connector for NetSuite](https://www.zuora.com/connect/app/?appId&#x3D;265).  | [optional] 
**transaction__ns** | **str** | Related transaction in NetSuite. Only available if you have installed the [Zuora Connector for NetSuite](https://www.zuora.com/connect/app/?appId&#x3D;265).  | [optional] 
**account_id** | **str** | The ID of the customer account associated with the credit memo. | [optional] 
**account_number** | **str** | The number of the account associated with the credit memo. | [optional] 
**amount** | **float** | The total amount of the credit memo. | [optional] 
**applied_amount** | **float** | The applied amount of the credit memo. | [optional] 
**auto_apply_upon_posting** | **bool** | Whether the credit memo automatically applies to the invoice upon posting. | [optional] 
**bill_to_contact_id** | **str** | The ID of the bill-to contact associated with the credit memo. The value of this field is &#x60;null&#x60; if you have the [Flexible Billing Attributes](https://knowledgecenter.zuora.com/Billing/Subscriptions/Flexible_Billing_Attributes) feature disabled. | [optional] 
**cancelled_by_id** | **str** | The ID of the Zuora user who cancelled the credit memo. | [optional] 
**cancelled_on** | **str** | The date and time when the credit memo was cancelled, in &#x60;yyyy-mm-dd hh:mm:ss&#x60; format. | [optional] 
**comment** | **str** | Comments about the credit memo. | [optional] 
**created_by_id** | **str** | The ID of the Zuora user who created the credit memo. | [optional] 
**created_date** | **str** | The date and time when the credit memo was created, in &#x60;yyyy-mm-dd hh:mm:ss&#x60; format. For example, 2017-03-01 15:31:10. | [optional] 
**credit_memo_date** | **date** | The date when the credit memo takes effect, in &#x60;yyyy-mm-dd&#x60; format. For example, 2017-05-20. | [optional] 
**currency** | **str** | A currency defined in the web-based UI administrative settings. | [optional] 
**exclude_from_auto_apply_rules** | **bool** | Whether the credit memo is excluded from the rule of automatically applying unapplied credit memos to invoices and debit memos during payment runs. | [optional] 
**id** | **str** | The unique ID of the credit memo. | [optional] 
**invoice_group_number** | **str** | The number of invoice group associated with the credit memo.  **Note**: This field is available only if you have the &lt;a href&#x3D;\&quot;https://knowledgecenter.zuora.com/Zuora_Billing/Bill_your_customers/Bill_customers_at_subscription_level/Flexible_Billing_Attributes\&quot; target&#x3D;\&quot;_blank\&quot;&gt;Flexible Billing Attributes&lt;/a&gt; feature enabled.  | [optional] 
**revenue_impacting** | [**MemoRevenueImpacting**](MemoRevenueImpacting.md) |  | [optional] 
**latest_pdf_file_id** | **str** | The ID of the latest PDF file generated for the credit memo.  | [optional] 
**number** | **str** | The unique identification number of the credit memo.  | [optional] 
**posted_by_id** | **str** | The ID of the Zuora user who posted the credit memo.  | [optional] 
**posted_on** | **str** | The date and time when the credit memo was posted, in &#x60;yyyy-mm-dd hh:mm:ss&#x60; format. | [optional] 
**reason_code** | **str** | A code identifying the reason for the transaction. The value must be an existing reason code or empty. | [optional] 
**referred_invoice_id** | **str** | The ID of a referred invoice. | [optional] 
**refund_amount** | **float** | The amount of the refund on the credit memo. | [optional] 
**reversed** | **bool** | Whether the credit memo is reversed. | [optional] 
**sequence_set_id** | **str** | The ID of the sequence set associated with the credit memo. The value of this field is &#x60;null&#x60; if you have the [Flexible Billing Attributes](https://knowledgecenter.zuora.com/Billing/Subscriptions/Flexible_Billing_Attributes) feature disabled. | [optional] 
**source** | **str** | The source of the credit memo.  Possible values: - &#x60;BillRun&#x60;: The credit memo is generated by a bill run. - &#x60;API&#x60;: The credit memo is created by calling the [Invoice and collect](https://www.zuora.com/developer/api-references/api/operation/Post_TransactionInvoicePayment) operation, or by calling the Orders, Order Line Items, or Fulfillments API operations. - &#x60;ApiSubscribe&#x60;: The credit memo is created by calling the [Create subscription](https://www.zuora.com/developer/api-references/api/operation/Post_Subscription) and [Create account](https://www.zuora.com/developer/api-references/api/operation/Post_Account) operation. - &#x60;ApiAmend&#x60;: The credit memo is created by calling the [Update subscription](https://www.zuora.com/developer/api-references/api/operation/Put_Subscription) operation. - &#x60;AdhocFromPrpc&#x60;: The credit memo is created from a product rate plan charge through the Zuora UI or by calling the [Create a credit memo from a charge](https://www.zuora.com/developer/api-references/api/operation/Post_CreditMemoFromPrpc) operation. - &#x60;AdhocFromInvoice&#x60;: The credit memo is created from an invoice or created by reversing an invoice. You can create a credit memo from an invoice through the Zuora UI or by calling the [Create credit memo from invoice](https://www.zuora.com/developer/api-references/api/operation/Post_CreditMemoFromInvoice) operation. You can create a credit memo by reversing an invoice through the Zuora UI or by calling the [Reverse invoice](https://www.zuora.com/developer/api-references/api/operation/Put_ReverseInvoice) operation. | [optional] 
**source_id** | **str** | The ID of the credit memo source.   If a credit memo is generated from a bill run, the value is the number of the corresponding bill run. Otherwise, the value is &#x60;null&#x60;.  | [optional] 
**source_type** | [**MemoSourceType**](MemoSourceType.md) |  | [optional] 
**status** | [**BillingDocumentStatus**](BillingDocumentStatus.md) |  | [optional] 
**target_date** | **date** | The target date for the credit memo, in &#x60;yyyy-mm-dd&#x60; format. For example, 2017-07-20.  | [optional] 
**tax_amount** | **float** | The amount of taxation. | [optional] 
**tax_message** | **str** | The message about the status of tax calculation related to the credit memo. If tax calculation fails in one credit memo, this field displays the reason for the failure. | [optional] 
**tax_status** | [**TaxStatus**](TaxStatus.md) |  | [optional] 
**total_tax_exempt_amount** | **float** | The calculated tax amount excluded due to the exemption. | [optional] 
**transferred_to_accounting** | [**TransferredToAccountingStatus**](TransferredToAccountingStatus.md) |  | [optional] 
**tax_auto_calculation** | **bool** | Whether to automatically calculate taxes in the credit memo. | [optional] 
**unapplied_amount** | **float** | The unapplied amount of the credit memo. | [optional] 
**updated_by_id** | **str** | The ID of the Zuora user who last updated the credit memo. | [optional] 
**updated_date** | **str** | The date and time when the credit memo was last updated, in &#x60;yyyy-mm-dd hh:mm:ss&#x60; format. For example, 2017-03-02 15:36:10. | [optional] 
**e_invoice_status** | [**EInvoiceStatus**](EInvoiceStatus.md) |  | [optional] 
**e_invoice_error_code** | **str** | eInvoiceErrorCode.  | [optional] 
**e_invoice_error_message** | **str** | eInvoiceErrorMessage.  | [optional] 
**e_invoice_file_id** | **str** | eInvoiceFileId.  | [optional] 
**bill_to_contact_snapshot_id** | **str** | billToContactSnapshotId.  | [optional] 
**organization_label** | **str** | organization label.  | [optional] 

## Example

```python
from zuora_sdk.models.credit_memo import CreditMemo

# TODO update the JSON string below
json = "{}"
# create an instance of CreditMemo from a JSON string
credit_memo_instance = CreditMemo.from_json(json)
# print the JSON string representation of the object
print(CreditMemo.to_json())

# convert the object into a dict
credit_memo_dict = credit_memo_instance.to_dict()
# create an instance of CreditMemo from a dict
credit_memo_from_dict = CreditMemo.from_dict(credit_memo_dict)
```
[[Back to Model list]](../README.md#documentation-for-models) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to README]](../README.md)


